@@ -5,7 +5,7 @@ use strict;
 use Exporter 'import';
 use Carp;
 
-our $VERSION = '0.002';  # rrr.mmmsss : rrr is major revision; mmm is minor revision; sss is sub-revision; optionally use _sss instead, for alpha sub-releases
+our $VERSION = '0.003';  # rrr.mmmsss : rrr is major revision; mmm is minor revision; sss is sub-revision; optionally use _sss instead, for alpha sub-releases
 
 use Win32::Mechanize::NotepadPlusPlus::Notepad ':vars';
 use Win32::Mechanize::NotepadPlusPlus::Editor ':vars';
@@ -28,6 +28,20 @@ Notepad++ plugin PythonScript, but I decided to automate the application from th
 from inside a Notepad++ plugin.  But this module uses similar naming conventions and interface to the
 PythonScript plugin.
 
+=head2 REQUIREMENTS
+
+You need to have Notepad++ on your system.
+
+This module will work if Notepad++ is in a standard install location, like C<%ProgramFiles%\Notepad++\>
+or C<%ProgramFiles(x86)%\Notepad++\>, or if it is in your path: when it can find the executable,
+it will either use the currently-running instance, or will launch a new instance if none are
+currently running.  If it cannot find your executable, the will only work if Notepad++ is
+already running.
+
+The module was developed with Notepad++ v7.7 or newer in mind, though some features should still
+work on older versions of Notepad++.  As Notepad++ adds new features, the minimum version for
+that method will be indicated in the help.
+
 =cut
 
 our @EXPORT = ();   # by default, export nothing
@@ -37,7 +51,7 @@ our @EXPORT_OTHER = qw//;   # maybe eventually, functions to create and destroy
 our @EXPORT_OK = (@EXPORT_MAIN, @EXPORT_VARS, @EXPORT_OTHER);
 our %EXPORT_TAGS = (
     main            => [@EXPORT_MAIN],
-    other           => [@EXPORT_OTHER],
+    #other           => [@EXPORT_OTHER],
     vars            => [@EXPORT_VARS],
     all             => [@EXPORT_OK],
 );
@@ -136,6 +150,10 @@ L<Win32::Mechanize::NotepadPlusPlus::Editor::Messages>
     # from Notepad::Messages: %NPPMSG, %VIEW, %MODELESS, %STATUSBAR, %MENUHANDLE, %INTERNALVAR, %LANGTYPE, %WINVER, %WINPLATFORM, %NOTIFICATION, %DOCSTATUS, %NPPIDM, %ENCODINGKEY
     # from Editor::Messages: %SCIMSG, %SCINTILLANOTIFICATION, and more than 50 others.
 
+=item :all
+
+Exports everything from L</":main"> and L</":vars">.
+
 =back
 
 =head1 LIMITATIONS
@@ -169,6 +187,37 @@ For a manual install, type the following:
 
 (On Windows machines, you may need to use "dmake" or "gmake" instead of "make", depending on your setup.)
 
+=head2 It didn't install
+
+In general, if the test suite fails and it doesn't install, you will probably need to file a
+L<bug report|https://github.com/pryrt/Win32-Mechanize-NotepadPlusPlus/issues>.
+
+Known possible causes include
+
+=over
+
+=item * Bit mismatch
+
+Notepad++ and Perl must have the same bits -- 64bit or 32bit.  Make sure they do.
+If they don't, it will fail in test file C<t\02_bits.t>.
+
+=item * C<-1 NOT E<gt>= 0> error
+
+See L<issue #28|https://github.com/pryrt/Win32-Mechanize-NotepadPlusPlus/issues/28>:
+if you get the message
+C<SendMessage_getRawString(): -1 NOT E<gt>= 0 at C:\usr\local\share\GitHubSvn\Win32-Mechanize-NotepadPlusPlus\lib/Win32/Mechanize/NotepadPlusPlus/Notepad.pm line 755.>
+or similar in multiple of the test files, it might be because you have one or
+more really large files currently open in Notepad++, or you have too many
+files open.  Either of these can cause a race condition where the test suite
+expects Notepad++ to respond with all files loaded, but Notepad++ isn't quite
+ready yet.  In that case, B<File E<gt> Save Session>, then
+B<File E<gt> Close All>.  Exit and restart Notepad++.  The test suite will
+probably pass now (if not, please comment on issue#28).  Once passing and
+installed, you can B<File E<gt> Load Session> to restore your previously
+active file session.
+
+=back
+
 =head1 AUTHOR
 
 Peter C. Jones C<E<lt>petercj AT cpan DOT orgE<gt>>
@@ -180,7 +229,7 @@ or thru the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Wi
 
 =begin html
 
-<a href="https://metacpan.org/pod/Win32::Mechanize::NotepadPlusPlus><img src="https://img.shields.io/cpan/v/Win32-Mechanize-NotepadPlusPlus.svg?colorB=00CC00" alt="" title="metacpan"></a>
+<a href="https://metacpan.org/pod/Win32::Mechanize::NotepadPlusPlus"><img src="https://img.shields.io/cpan/v/Win32-Mechanize-NotepadPlusPlus.svg?colorB=00CC00" alt="" title="metacpan"></a>
 <a href="http://matrix.cpantesters.org/?dist=Win32-Mechanize-NotepadPlusPlus"><img src="http://cpants.cpanauthors.org/dist/Win32-Mechanize-NotepadPlusPlus.png" alt="" title="cpan testers"></a>
 <a href="https://github.com/pryrt/Win32-Mechanize-NotepadPlusPlus/releases"><img src="https://img.shields.io/github/release/pryrt/Win32-Mechanize-NotepadPlusPlus.svg" alt="" title="github release"></a>
 <a href="https://github.com/pryrt/Win32-Mechanize-NotepadPlusPlus/issues"><img src="https://img.shields.io/github/issues/pryrt/Win32-Mechanize-NotepadPlusPlus.svg" alt="" title="issues"></a>
